@@ -24,10 +24,10 @@
  *
  * Please send any bug reports or fixes you make to the
  * email address(es):
- *    lksctp developers <lksctp-developers@lists.sourceforge.net>
+ *    lksctp developers <linux-sctp@vger.kernel.org>
  *
  * Or submit a bug report through the following website:
- *    http://www.sf.net/projects/lksctp
+ *    https://github.com/sctp/lksctp-tools/
  *
  * Any bugs reported to us we will try to fix... any fixes shared will
  * be incorporated into the next SCTP release.
@@ -1142,6 +1142,7 @@ main(void)
 	close(accept_sk);
 	close(peeloff_sk);
 
-        /* Indicate successful completion.  */
-        return 0;
+	free(big_buffer);
+	/* Indicate successful completion.  */
+	return 0;
 }
